EKF SPV-MYSTIC — ekfsm documentation

# EKF SPV-MYSTIC

See Product Page for the board’s technical specifications.

## Inventory

The inventory function provides access to the inventory, such as the vendor, model, serial number (taken from the board’s EEPROM), and revision (from the board’s GPIO device).

Method | Description | Example Value
`vendor()` | Get the board vendor | `EKF`
`model()` | Get the board model | `SUR-UART`
`serial()` | Get the board serial number | `12345678`
`revision()` | Get the board revision | `1`

## GPIOs (Objects: gpio0, gpio1, gpio2)

The EKF SPV-MYSTIC board has three 8-bit GPIOs that can be used to control the modems and other peripherals on the board. Consult the hardware documentation for the usage of the GPIOs.

Method | Description | Example Value
`num_lines()` | Get number of GPIO lines available | `8`
`set_direction()` | Set the direction of a GPIO pin | `0`, `True`
`set_pin()` | Set the value of a GPIO pin | `0`, `True`
`get_pin()` | Get the value of a GPIO pin | `True`